#!/bin/sh
#Version 1.1 26/6/2007
#Crossware Mail Signature Installation for Solaris and Linux
#V1.0 DS - 31/5/2007 Initial Coding
#V1.1 DS - 29/6/2007 Added Check for OS Type and support fort LINUX
#V1.2 DS - 7/11/2007 Updated for ICU3.6 to support Dom8 on Linux
#V1.3 DS - 26/3/2008 Added support for AIX
#V1.4 DS - 16/4/2008 Added libicui18n to installation package
#V1.5 DS - 22/7/2008 Set permissions on copied files correcly
#V1.6 DS - 28/8/2008 Force remove of extsing files
#V1.7 DS - 28/8/2008 Add zLinux and make all icu libraries with xware suffix
#V1.8 DS - 24/7/2009 tar files compressed
#V1.9 DS - 21/8/2009 make TARFILE command to extract file as different of different plafforms
#V1.10 DS - 28/10/2009 Made installer 32 and 64bit zLinux aware
#V1.11 DS - 11/02/2010 Made installer 32 and 64bit AIX aware
#V1.12 DS - 09/07/2011 Updated sigfiles for linux using .38 icu libraries
#v1.13 DS - 10/09/2012 Updated Solaris ICU libraries
#v1.14 DS - 29/04/2013 Added support for 64bit linux
echo "Installing Crossware Mail Signature....."

if [ -z "$Notes_ExecDirectory" ]; then
	echo "Notes_ExecDirectory Environment variable not found. Checking command line"
	if [ -z "$1" ]; then
		echo "Path to Domino Application directory not specified on command line. Unable to continue"  
		exit 1
	else 
		echo "Using path specified on command line"    
		ESIGINSTALLDIR=$1
	fi
else
	ESIGINSTALLDIR=$Notes_ExecDirectory
fi

#check that the directory exists
if [ -d "$ESIGINSTALLDIR" ]; then
	echo "Found Installation Directory"
else
	echo "Installation Directory not found. Unable to continue"
	exit
fi	


uname=uname
#AIX
if [ `$uname` = AIX ]; then
	echo "Detected AIX "

	AIXTest="$1/libnotes_r.a"
	a64=`file $AIXTest |grep 64-bit 2>&1`
	a32=`file $AIXTest |grep RISC 2>&1`
	if [ -z "$a64" ];then
        	if [ -z "$a32" ];then
                	echo Unable to determine weather domino if 32 or 64 bit
			exit
	        else
        	        echo Detected 32bit domino on AIX
			TARFILE="zcat ../signature_aix32.tar.Z | tar xvf -"

	        fi
	else
        	echo Detected 64bit domino on AIX
		TARFILE="zcat ../signature_aix64.tar.Z | tar xvf -"

	fi
	sig_files="esig libsignature.a libicuucxware36.a libicudataxware36.a libicui18nxware.a"
	dimfile="$ESIGINSTALLDIR"/libnotes_r.a
fi

#HP-UX
if [ `$uname` = HP-UX ]; then
	echo "HP-UX is unsupported at this time. Unable to continue"
	exit
fi

#SOLARIS
if [ `$uname` = SunOS ]; then

    	if [ `$uname -p` = sparc ]; then
		echo "Detected SOLARIS"
		TARFILE="zcat ../signature_sol.tar.Z | tar xvf -"
		sig_files="esig libsignature.so libicuucxware.so.38 libicudataxware.so.38 libicui18nxware.so.38"
		dimfile="$ESIGINSTALLDIR"/libnotes.so

	else
		echo "SOLARIS on x86 is unsupported at this time. Unable to continue"
		exit
    	fi

fi

#LINUX
if [ `$uname` = Linux ]; then
    if [ `$uname -m` = s390x ]; then
    	echo "Detected zLINUX(64Bit)"
	TARFILE="tar xzf ../signature_zlinux64.tgz"
	sig_files="esig libsignature.so libicuucxware.so.36 libicudataxware.so.36 libicui18nxware.so.36"
	dimfile="$ESIGINSTALLDIR"/libnotes.so

    else

	if [ `$uname -m` = s390 ]; then
    		echo "Detected zLINUX(31bit)"
		TARFILE="tar xzf ../signature_zlinux32.tgz"
		sig_files="esig libsignature.so libicuucxware.so.36 libicudataxware.so.36 libicui18nxware.so.36"
		dimfile="$ESIGINSTALLDIR"/libnotes.so

	else
		echo "Detected LINUX"
		LINTest="$1/libnotes.so"
		l64=`file $LINTest |grep 64-bit 2>&1`
		l32=`file $LINTest |grep 32-bit 2>&1`
	if [ -z "$l64" ];then
        	if [ -z "$l32" ];then
                	echo Unable to determine weather domino if 32 or 64 bit
			exit
	        else
        	    echo Detected 32bit domino on Linux
				TARFILE="tar xzf ../signature_linux32.tgz"
				#sig_files="esig libsignature.so libicuucxware.so.36 libicudataxware.so.36 libicui18nxware.so.36"
				sig_files="esig libsignature.so libicuucxware.so.38 libicudataxware.so.38 libicui18nxware.so.38"
				dimfile="$ESIGINSTALLDIR"/libnotes.so

	        fi
	else
        	echo Detected 64bit domino on Linux
			TARFILE="tar xzf ../signature_linux64.tgz"
			#sig_files="esig libsignature.so libicuucxware.so.36 libicudataxware.so.36 libicui18nxware.so.36"
			sig_files="esig libsignature.so libicuucxware.so.38 libicudataxware.so.38 libicui18nxware.so.38"
			dimfile="$ESIGINSTALLDIR"/libnotes.so

	fi
		
		
		
		
		
	fi
    fi
fi


if [ -z "$TARFILE" ]; then
	echo "Unknown OS $uname, unable to continue"
	exit
fi


	


echo "Checking for domino installation..."
#check for notes installed
if [ -f "$dimfile" ]; then
	echo "Confirmed Domino Application directory"   
else
	echo "Directory does not contain a Domino Application"
	exit
fi



#note create a temp directory below this one
if [ -d ./esigtempinst ]; then
	#clear out this install dir ready for a new extract
	echo "Creating existing temporary installation directory"  
	rm -f ./esigtempinst/*  
else
	echo "Creating temporary installtion directory"
	mkdir ./esigtempinst
fi

#extract our tar file into the temp dir

cd esigtempinst
echo "Extracting files to temp directory....."   










echo "Extracting executables $TARFILE"
eval $TARFILE




for X in $sig_files; do
        echo "copying file $ESIGINSTALLDIR/$X"
	cp -f $X $ESIGINSTALLDIR
	chmod 755 $ESIGINSTALLDIR/$X
done 



if [ `$uname` = AIX ]; then

        echo "Creating AIX icu sym link"
        ln -s $ESIGINSTALLDIR/libicuucxware36.a $ESIGINSTALLDIR/libicuucxware.a

fi


echo "Installation complete. Please update your notes.ini file"    






